# Contributing to Pyarallel

We love your input! We want to make contributing to Pyarallel as easy and transparent as possible, whether it's:

- Reporting a bug
- Discussing the current state of the code
- Submitting a fix
- Proposing new features
- Becoming a maintainer

## Development Process

We use GitHub to host code, to track issues and feature requests, as well as accept pull requests.

1. Fork the repo and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. Issue that pull request!

## Any Contributions You Make Will Be Under the MIT License
In short, when you submit code changes, your submissions are understood to be under the same [MIT License](http://choosealicense.com/licenses/mit/) that covers the project. Feel free to contact the maintainers if that's a concern.

## Report Bugs Using GitHub's [Issue Tracker](https://github.com/oneryalcin/pyarallel/issues)  

We use GitHub issues to track public bugs. Report a bug by [opening a new issue](https://github.com/oneryalcin/pyarallel/issues/new); it's that easy!

## Write Bug Reports With Detail, Background, and Sample Code

**Great Bug Reports** tend to have:

- A quick summary and/or background
- Steps to reproduce
  - Be specific!
  - Give sample code if you can.
- What you expected would happen
- What actually happens
- Notes (possibly including why you think this might be happening, or stuff you tried that didn't work)

## Use a Consistent Coding Style

* Use [Black](https://github.com/psf/black) for Python code formatting
* Keep line length to 88 characters (Black default)
* Use type hints for function arguments and return values
* Write docstrings for all public functions and classes

## Running Tests

```bash
pytest tests/
```

## License

By contributing, you agree that your contributions will be licensed under its MIT License.
